==> jc-1.4.0.tar.gz: java__5fcup/sym.h <==
// public class java_cup.sym

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d85044d941e940d6 java__5fcup_sym

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_sym_H_
#define _JC_java__5fcup_sym_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java__5fcup_sym$sub_refs	_jc_java__5fcup_sym$sub_refs;
typedef struct _jc_java__5fcup_sym$sub_nonrefs	_jc_java__5fcup_sym$sub_nonrefs;
typedef struct _jc_java__5fcup_sym$refs	_jc_java__5fcup_sym$refs;
typedef struct _jc_java__5fcup_sym$nonrefs	_jc_java__5fcup_sym$nonrefs;
typedef struct _jc_java__5fcup_sym$object	_jc_java__5fcup_sym$object;

typedef struct _jc_java__5fcup_sym$fields_struct	_jc_java__5fcup_sym$fields_struct;
typedef const struct _jc_java__5fcup_sym$vmethods	_jc_java__5fcup_sym$vmethods;
typedef const struct _jc_java__5fcup_sym$vtable	_jc_java__5fcup_sym$vtable;
typedef const struct _jc_java__5fcup_sym$vtype	_jc_java__5fcup_sym$vtype;

// Class fields structure
struct _jc_java__5fcup_sym$fields_struct {
	jint	ACTION;
	jint	BAR;
	jint	CODE;
	jint	CODE__5fSTRING;
	jint	COLON;
	jint	COLON__5fCOLON__5fEQUALS;
	jint	COMMA;
	jint	DOT;
	jint	EOF;
	jint	ID;
	jint	IMPORT;
	jint	INIT;
	jint	LBRACK;
	jint	LEFT;
	jint	NON;
	jint	NONASSOC;
	jint	NONTERMINAL;
	jint	PACKAGE;
	jint	PARSER;
	jint	PERCENT__5fPREC;
	jint	PRECEDENCE;
	jint	RBRACK;
	jint	RIGHT;
	jint	SCAN;
	jint	SEMI;
	jint	STAR;
	jint	START;
	jint	TERMINAL;
	jint	WITH;
	jint	error;
};
extern _jc_java__5fcup_sym$fields_struct _jc_java__5fcup_sym$class_fields;

// Constructors
extern void _jc_java__5fcup_sym$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java__5fcup_sym$object *);

// Virtual methods structure
struct _jc_java__5fcup_sym$vmethods {
};

// Vtable
struct _jc_java__5fcup_sym$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_sym$vmethods	java__5fcup_sym;
};

// Vtype
struct _jc_java__5fcup_sym$vtype {
	_jc_type			type;
	_jc_java__5fcup_sym$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_sym$sub_refs {
};

// Reference instance fields (object)
struct _jc_java__5fcup_sym$refs {
    _jc_java__5fcup_sym$sub_refs	java__5fcup_sym;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_sym$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_sym$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_sym$sub_nonrefs	java__5fcup_sym;
};

// Object instance structure
struct _jc_java__5fcup_sym$object {
	_jc_java__5fcup_sym$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_sym$vtype	*vtype;
	_jc_java__5fcup_sym$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_sym$vtype _jc_java__5fcup_sym$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_sym, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_sym$class_object;

#endif	/* _JC_java__5fcup_sym_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/sym.h <==
// public class java_cup.sym

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d85044d941e940d6 java__5fcup_sym

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_sym_H_
#define _JC_java__5fcup_sym_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java__5fcup_sym$sub_refs	_jc_java__5fcup_sym$sub_refs;
typedef struct _jc_java__5fcup_sym$sub_nonrefs	_jc_java__5fcup_sym$sub_nonrefs;
typedef struct _jc_java__5fcup_sym$refs	_jc_java__5fcup_sym$refs;
typedef struct _jc_java__5fcup_sym$nonrefs	_jc_java__5fcup_sym$nonrefs;
typedef struct _jc_java__5fcup_sym$object	_jc_java__5fcup_sym$object;

typedef struct _jc_java__5fcup_sym$fields_struct	_jc_java__5fcup_sym$fields_struct;
typedef const struct _jc_java__5fcup_sym$vmethods	_jc_java__5fcup_sym$vmethods;
typedef const struct _jc_java__5fcup_sym$vtable	_jc_java__5fcup_sym$vtable;
typedef const struct _jc_java__5fcup_sym$vtype	_jc_java__5fcup_sym$vtype;

// Class fields structure
struct _jc_java__5fcup_sym$fields_struct {
	jint	ACTION;
	jint	BAR;
	jint	CODE;
	jint	CODE__5fSTRING;
	jint	COLON;
	jint	COLON__5fCOLON__5fEQUALS;
	jint	COMMA;
	jint	DOT;
	jint	EOF;
	jint	ID;
	jint	IMPORT;
	jint	INIT;
	jint	LBRACK;
	jint	LEFT;
	jint	NON;
	jint	NONASSOC;
	jint	NONTERMINAL;
	jint	PACKAGE;
	jint	PARSER;
	jint	PERCENT__5fPREC;
	jint	PRECEDENCE;
	jint	RBRACK;
	jint	RIGHT;
	jint	SCAN;
	jint	SEMI;
	jint	STAR;
	jint	START;
	jint	TERMINAL;
	jint	WITH;
	jint	error;
};
extern _jc_java__5fcup_sym$fields_struct _jc_java__5fcup_sym$class_fields;

// Constructors
extern void _jc_java__5fcup_sym$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java__5fcup_sym$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java__5fcup_sym$vmethods {
};

// Vtable
struct _jc_java__5fcup_sym$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_sym$vmethods	java__5fcup_sym;
};

// Vtype
struct _jc_java__5fcup_sym$vtype {
	_jc_type			type;
	_jc_java__5fcup_sym$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_sym$sub_refs {
};

// Reference instance fields (object)
struct _jc_java__5fcup_sym$refs {
    _jc_java__5fcup_sym$sub_refs	java__5fcup_sym;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_sym$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_sym$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_sym$sub_nonrefs	java__5fcup_sym;
};

// Object instance structure
struct _jc_java__5fcup_sym$object {
	_jc_java__5fcup_sym$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_sym$vtype	*vtype;
	_jc_java__5fcup_sym$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_sym$vtype _jc_java__5fcup_sym$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_sym, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_sym$class_object;

#endif	/* _JC_java__5fcup_sym_H_ */
